aboutsummaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authorJohn Baldwin <jhb@FreeBSD.org>2001-02-09 17:35:22 +0000
committerJohn Baldwin <jhb@FreeBSD.org>2001-02-09 17:35:22 +0000
commite761636a4b543ec4ceb5b75c4bc34e1ea812f078 (patch)
tree3a9b10821c2e1b358302d7213c834abcbd207c66 /sys
parentf512a26419d4908f606078c07eafb9d58d8f483a (diff)
Notes
Diffstat (limited to 'sys')
-rw-r--r--sys/sys/bus.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/sys/sys/bus.h b/sys/sys/bus.h
index ac583a74a0dc..bfa4105324c2 100644
--- a/sys/sys/bus.h
+++ b/sys/sys/bus.h
@@ -87,12 +87,11 @@ enum intr_type {
INTR_TYPE_NET = 4,
INTR_TYPE_CAM = 8,
INTR_TYPE_MISC = 16,
- INTR_HEAVY = 32, /* heavyweight interrupt process */
- INTR_LIGHT = 64, /* light weight interrupt thread */
- INTR_THREADED = INTR_LIGHT | INTR_HEAVY, /* any kind of interrupt thread */
+ INTR_TYPE_CLK = 32,
INTR_FAST = 128,
INTR_EXCL = 256, /* exclusive interrupt */
- INTR_MPSAFE = 512 /* this interrupt is SMP safe */
+ INTR_MPSAFE = 512, /* this interrupt is SMP safe */
+ INTR_ENTROPY = 1024 /* this interrupt provides entropy */
};
typedef int (*devop_t)(void);